<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * e.g., it puts together the home page when no home.php file exists.
 *
 * Learn more: {@link https://codex.wordpress.org/Template_Hierarchy}
 *
 * @package WordPress
 * @subpackage seothemes
 * @since seothemes 1.0
 */

get_header();

$layout_model = get_theme_mod( 'layout_model', 'inner-list' );
?>
<section id="main-container" class="container">
	<div class="row">
			<main id="main" class="col-sm-12 col-md-8 col-xs-12" role="main">
<?php if(is_author()): ?>
<div class="author-artikel">
	<div class="d-flex align-items-center">
		<div class="flex-shrink-0">
			<?php echo get_avatar( get_the_author_meta( 'user_email' ),80 ); ?>
		</div>
		<!-- .author-avatar -->
		<div class="flex-grow-1 ms-3">
			<h1 class="text-uppercase heading-optimasi">
				<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>">
					<?php echo get_the_author(); ?>
				</a>
			</h1>
			<?php if (function_exists('seothemes_breadcrumbs')) seothemes_breadcrumbs(); ?>
			<?php if(!empty($description)): ?>
			<p class="author-deskripsi small"><?php the_author_meta( 'description' ); ?></p>
			<?php endif ?>
			<div class="author-links">
				<?php
					if ( ! empty( get_the_author_meta( 'user_url' ) ) ) :
						printf( '<a href="%s" class="badge rounded-pill text-bg-secondary" rel="nofollow">' . esc_html__( 'Website') . '</a>', esc_url( get_the_author_meta( 'user_url' ) ) );
					endif;

					// Add new Profile fields for Users in functions.php
					$fields = array(
						array(
							'meta'  => 'facebook',
							'label' => 'Facebook',
						),
						array(
							'meta'  => 'twitter',
							'label' => 'Twitter',
						),
						array(
							'meta'  => 'instagram',
							'label' => 'Instagram',
						),
						array(
							'meta'  => 'youtube',
							'label' => 'Youtube',
						),
					);

					foreach ( $fields as $key => $data ) {
						$author_link = get_the_author_meta( esc_attr( $data['meta'] ) );
						if ( ! empty( $author_link ) ) {
							$label = $data['label'];
							echo ' <a href="' . esc_url( $author_link ) . '" class="badge rounded-pill text-bg-secondary" rel="nofollow" title="' . esc_attr( $label ) . '">' . esc_html( $label ) . '</a> ';
						}
					}
				?>
			</div>
		</div>
	</div>
</div>
<?php else: ?>
<div class="box-optimasi alert">
			    <h1 class="text-uppercase heading-optimasi"><?php the_archive_title(); ?></h1>
			    <?php if (function_exists('seothemes_breadcrumbs')) seothemes_breadcrumbs(); ?>
			    <?php the_archive_description( );?>
			</div>
<?php endif ?> 

			<?php if ( isset( $layout_model ) && 'inner-grid' === $layout_model ) : echo '<div class="row">'; endif; ?>
			
			<?php if ( have_posts() ) : ?>
			    <?php while ( have_posts() ) : the_post(); ?>
			    <?php if ( isset( $layout_model ) && 'inner-list' === $layout_model ) : get_template_part( 'template/loop/inner-list' ); elseif ( isset( $layout_model ) && 'inner-grid' === $layout_model ) : get_template_part( 'template/loop/inner-grid' ); endif; ?>
                <?php endwhile; ?>
				<?php seothemes_paging_nav();

			// If no content, include the "No posts found" template.
			else :
				get_template_part( 'template/content', 'none' );

			endif;
			?>
			
			<?php if ( isset( $layout_model ) && 'inner-grid' === $layout_model ) : echo '</div>'; endif; ?>

			</main><!-- .site-main -->
			<!-- .content-area -->
		
		<?php get_sidebar( ); ?>
		
	</div>
</section>
<?php get_footer(); ?>