<?php

define('THEME_NAME', 'seothemes');
define('THEME_VERSION', '2.3.4');

if ( ! function_exists( 'seothemes_setup' ) ) :
    
function seothemes_setup() {
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	if ( function_exists( 'add_theme_support' ) ) { 
    add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size( 150, 150, true ); // default Post Thumbnail dimensions (cropped)
    }
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
	add_theme_support( 'customize-selective-refresh-widgets' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'editor-styles' );
	add_theme_support( 'responsive-embeds' );
	
	register_nav_menus( array( 'header-menu' => __( 'Menu Header', 'seothemes' ) ) );
    register_nav_menus( array( 'footer-menu' => __( 'Menu Footer', 'seothemes' ) ) );
}
endif; // seothemes_setup
add_action( 'after_setup_theme', 'seothemes_setup' );

function seothemes_enqueue_styles() {
	//load font awesome
	wp_enqueue_style( 'all-awesome', get_template_directory_uri() . '/assets/vendor/fontawesome/css/all.css', array(), 'v6.1.1' );
	// load bootstrap style
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/vendor/bootstrap/css/bootstrap.css', array(), '5.2.0' );
	// main style
	wp_enqueue_style( 'seothemes-template', get_template_directory_uri() . '/assets/css/template.css', array(), 'THEME_VERSION' );
}
add_action( 'wp_enqueue_scripts', 'seothemes_enqueue_styles', 100 );

function seothemes_enqueue_scripts() {
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	// bootstrap
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/vendor/bootstrap/js/bootstrap.bundle.js', array( 'jquery' ), '5.2.0', true );
	// main script
	wp_localize_script( 'seothemes-functions', 'seothemes_ajax', array(
		'previous' => esc_html__('Previous', 'seothemes'),
		'next' => esc_html__('Next', 'seothemes')
	));
	wp_enqueue_script( 'seothemes-functions' );
	
}
add_action( 'wp_enqueue_scripts', 'seothemes_enqueue_scripts', 1 );

function seothemes_get_config($name, $default = '') {
	global $seothemes_options;
    if ( isset($seothemes_options[$name]) ) {
        return $seothemes_options[$name];
    }
    return $default;
}

function seothemes_widgets_init() {
	register_sidebar( array(
        'name'          => __( 'Sidebar', 'seothemes' ),
        'id'            => 'sidebar',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );
}
add_action( 'widgets_init', 'seothemes_widgets_init' );

require get_template_directory() . '/inc/functions-helper.php';
require get_template_directory() . '/inc/functions-frontend.php';

function register_dashboard_seothemes() {
    add_submenu_page(
        'themes.php',
        'SEO THEMES',
        'SEO THEMES',
        'manage_options',
        'seothemes',
        'dashboard_seothemes_callback' );
}
add_action('admin_menu', 'register_dashboard_seothemes');

function dashboard_seothemes_callback() {
    require_once get_template_directory() . '/assets/admin/dashboard.php';
}

function admin_style() {
  wp_enqueue_style('admin-styles', get_template_directory_uri().'/assets/admin/style.css');
}
add_action('admin_enqueue_scripts', 'admin_style');

$aktifkan_index_berita  = get_theme_mod( 'aktifkan_index_berita', '' );
if ( '1' === $aktifkan_index_berita) :
require get_template_directory() . '/inc/functions-custom.php';
endif;

add_filter( 'gutenberg_use_widgets_block_editor', '__return_false' );
add_filter( 'use_widgets_block_editor', '__return_false' );

//Ubah judul arsip
function ubah_judul_arsip ( $title, $original_title ) { 
    return $original_title; 
} 
add_filter( 'get_the_archive_title', 'ubah_judul_arsip', 10, 2 );

//Register Custom Navigation Walker
function register_navwalker(){
    require_once get_template_directory() . '/inc/walker.php';
    require_once get_template_directory() . '/inc/walker2.php';
}
add_action( 'after_setup_theme', 'register_navwalker' );

//Ubah format postdate
function meks_time_ago() {
	return human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ).' '.__( 'lalu' );
}

// Ijinkan HTML di deskripsi ketegory dan tag
remove_filter( 'pre_term_description', 'wp_filter_kses' );
remove_filter( 'pre_link_description', 'wp_filter_kses' );
remove_filter( 'pre_link_notes', 'wp_filter_kses' );
remove_filter( 'term_description', 'wp_kses_data' );

require 'assets/vendor/checker/checker.php';
$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://social.or.id/seothemes.json',
	__FILE__, //Full path to the main plugin file or functions.php.
	'seothemes'
);

// register widget artikel terbaru + thumbnail
function terbaru_thumb_register_load_widget() {
	get_template_part( 'template/widgets/recent-post-thumb' );
	get_template_part( 'template/widgets/random-post-thumb' );
}
add_action( 'widgets_init', 'terbaru_thumb_register_load_widget' );